==> kubernetes-model-apps-5.3.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/apps/StatefulSetUpdateStrategyFluentImpl.java <==
package io.fabric8.kubernetes.api.model.apps;

import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class StatefulSetUpdateStrategyFluentImpl<A extends StatefulSetUpdateStrategyFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements StatefulSetUpdateStrategyFluent<A> {

    private RollingUpdateStatefulSetStrategyBuilder rollingUpdate;
    private String type;

    public StatefulSetUpdateStrategyFluentImpl() {
    }

    public StatefulSetUpdateStrategyFluentImpl(StatefulSetUpdateStrategy instance) {
        this.withRollingUpdate(instance.getRollingUpdate()); 
        this.withType(instance.getType()); 
    }

    
/**
 * This method has been deprecated, please use method buildRollingUpdate instead.
 * @return The buildable object.
 */
@Deprecated public RollingUpdateStatefulSetStrategy getRollingUpdate() {
        return this.rollingUpdate!=null?this.rollingUpdate.build():null;
    }

    public RollingUpdateStatefulSetStrategy buildRollingUpdate() {
        return this.rollingUpdate!=null?this.rollingUpdate.build():null;
    }

    public A withRollingUpdate(RollingUpdateStatefulSetStrategy rollingUpdate) {
        _visitables.get("rollingUpdate").remove(this.rollingUpdate);
        if (rollingUpdate!=null){ this.rollingUpdate= new RollingUpdateStatefulSetStrategyBuilder(rollingUpdate); _visitables.get("rollingUpdate").add(this.rollingUpdate);} return (A) this;
    }

    public Boolean hasRollingUpdate() {
        return this.rollingUpdate != null;
    }

    public A withNewRollingUpdate(Integer partition) {
        return (A)withRollingUpdate(new RollingUpdateStatefulSetStrategy(partition));
    }

    public StatefulSetUpdateStrategyFluent.RollingUpdateNested<A> withNewRollingUpdate() {
        return new RollingUpdateNestedImpl();
    }

    public StatefulSetUpdateStrategyFluent.RollingUpdateNested<A> withNewRollingUpdateLike(RollingUpdateStatefulSetStrategy item) {
        return new RollingUpdateNestedImpl(item);
    }

    public StatefulSetUpdateStrategyFluent.RollingUpdateNested<A> editRollingUpdate() {
        return withNewRollingUpdateLike(getRollingUpdate());
    }

    public StatefulSetUpdateStrategyFluent.RollingUpdateNested<A> editOrNewRollingUpdate() {
        return withNewRollingUpdateLike(getRollingUpdate() != null ? getRollingUpdate(): new RollingUpdateStatefulSetStrategyBuilder().build());
    }

    public StatefulSetUpdateStrategyFluent.RollingUpdateNested<A> editOrNewRollingUpdateLike(RollingUpdateStatefulSetStrategy item) {
        return withNewRollingUpdateLike(getRollingUpdate() != null ? getRollingUpdate(): item);
    }

    public String getType() {
        return this.type;
    }

    public A withType(String type) {
        this.type=type; return (A) this;
    }

    public Boolean hasType() {
        return this.type != null;
    }

    public A withNewType(StringBuilder arg1) {
        return (A)withType(new String(arg1));
    }

    public A withNewType(int[] arg1,int arg2,int arg3) {
        return (A)withType(new String(arg1, arg2, arg3));
    }

    public A withNewType(char[] arg1) {
        return (A)withType(new String(arg1));
    }

    public A withNewType(StringBuffer arg1) {
        return (A)withType(new String(arg1));
    }

    public A withNewType(byte[] arg1,int arg2) {
        return (A)withType(new String(arg1, arg2));
    }

    public A withNewType(byte[] arg1) {
        return (A)withType(new String(arg1));
    }

    public A withNewType(char[] arg1,int arg2,int arg3) {
        return (A)withType(new String(arg1, arg2, arg3));
    }

    public A withNewType(byte[] arg1,int arg2,int arg3) {
        return (A)withType(new String(arg1, arg2, arg3));
    }

    public A withNewType(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withType(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewType(String arg1) {
        return (A)withType(new String(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        StatefulSetUpdateStrategyFluentImpl that = (StatefulSetUpdateStrategyFluentImpl) o;
        if (rollingUpdate != null ? !rollingUpdate.equals(that.rollingUpdate) :that.rollingUpdate != null) return false;
        if (type != null ? !type.equals(that.type) :that.type != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(rollingUpdate,  type,  super.hashCode());
    }

    public class RollingUpdateNestedImpl<N> extends RollingUpdateStatefulSetStrategyFluentImpl<StatefulSetUpdateStrategyFluent.RollingUpdateNested<N>> implements StatefulSetUpdateStrategyFluent.RollingUpdateNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final RollingUpdateStatefulSetStrategyBuilder builder;

            RollingUpdateNestedImpl(RollingUpdateStatefulSetStrategy item) {
                this.builder = new RollingUpdateStatefulSetStrategyBuilder(this, item);
                        
            }

            RollingUpdateNestedImpl() {
                this.builder = new RollingUpdateStatefulSetStrategyBuilder(this);
                        
            }

            public N and() {
                return (N) StatefulSetUpdateStrategyFluentImpl.this.withRollingUpdate(builder.build());
            }

            public N endRollingUpdate() {
                return and();
            }
    }


}

==> kubernetes-model-apps-5.3.2-sources.jar: annotations/io/fabric8/kubernetes/api/model/apps/StatefulSetUpdateStrategyFluentImpl.java <==
package io.fabric8.kubernetes.api.model.apps;

import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class StatefulSetUpdateStrategyFluentImpl<A extends StatefulSetUpdateStrategyFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements StatefulSetUpdateStrategyFluent<A> {

    private RollingUpdateStatefulSetStrategyBuilder rollingUpdate;
    private String type;

    public StatefulSetUpdateStrategyFluentImpl() {
    }

    public StatefulSetUpdateStrategyFluentImpl(StatefulSetUpdateStrategy instance) {
        this.withRollingUpdate(instance.getRollingUpdate()); 
        this.withType(instance.getType()); 
    }

    
/**
 * This method has been deprecated, please use method buildRollingUpdate instead.
 * @return The buildable object.
 */
@Deprecated public RollingUpdateStatefulSetStrategy getRollingUpdate() {
        return this.rollingUpdate!=null?this.rollingUpdate.build():null;
    }

    public RollingUpdateStatefulSetStrategy buildRollingUpdate() {
        return this.rollingUpdate!=null?this.rollingUpdate.build():null;
    }

    public A withRollingUpdate(RollingUpdateStatefulSetStrategy rollingUpdate) {
        _visitables.get("rollingUpdate").remove(this.rollingUpdate);
        if (rollingUpdate!=null){ this.rollingUpdate= new RollingUpdateStatefulSetStrategyBuilder(rollingUpdate); _visitables.get("rollingUpdate").add(this.rollingUpdate);} return (A) this;
    }

    public Boolean hasRollingUpdate() {
        return this.rollingUpdate != null;
    }

    public A withNewRollingUpdate(Integer partition) {
        return (A)withRollingUpdate(new RollingUpdateStatefulSetStrategy(partition));
    }

    public io.fabric8.kubernetes.api.model.apps.StatefulSetUpdateStrategyFluent.RollingUpdateNested<A> withNewRollingUpdate() {
        return new RollingUpdateNestedImpl();
    }

    public io.fabric8.kubernetes.api.model.apps.StatefulSetUpdateStrategyFluent.RollingUpdateNested<A> withNewRollingUpdateLike(RollingUpdateStatefulSetStrategy item) {
        return new RollingUpdateNestedImpl(item);
    }

    public io.fabric8.kubernetes.api.model.apps.StatefulSetUpdateStrategyFluent.RollingUpdateNested<A> editRollingUpdate() {
        return withNewRollingUpdateLike(getRollingUpdate());
    }

    public io.fabric8.kubernetes.api.model.apps.StatefulSetUpdateStrategyFluent.RollingUpdateNested<A> editOrNewRollingUpdate() {
        return withNewRollingUpdateLike(getRollingUpdate() != null ? getRollingUpdate(): new RollingUpdateStatefulSetStrategyBuilder().build());
    }

    public io.fabric8.kubernetes.api.model.apps.StatefulSetUpdateStrategyFluent.RollingUpdateNested<A> editOrNewRollingUpdateLike(RollingUpdateStatefulSetStrategy item) {
        return withNewRollingUpdateLike(getRollingUpdate() != null ? getRollingUpdate(): item);
    }

    public String getType() {
        return this.type;
    }

    public A withType(String type) {
        this.type=type; return (A) this;
    }

    public Boolean hasType() {
        return this.type != null;
    }

    public A withNewType(StringBuilder arg1) {
        return (A)withType(new String(arg1));
    }

    public A withNewType(int[] arg1,int arg2,int arg3) {
        return (A)withType(new String(arg1, arg2, arg3));
    }

    public A withNewType(char[] arg1) {
        return (A)withType(new String(arg1));
    }

    public A withNewType(StringBuffer arg1) {
        return (A)withType(new String(arg1));
    }

    public A withNewType(byte[] arg1,int arg2) {
        return (A)withType(new String(arg1, arg2));
    }

    public A withNewType(byte[] arg1) {
        return (A)withType(new String(arg1));
    }

    public A withNewType(char[] arg1,int arg2,int arg3) {
        return (A)withType(new String(arg1, arg2, arg3));
    }

    public A withNewType(byte[] arg1,int arg2,int arg3) {
        return (A)withType(new String(arg1, arg2, arg3));
    }

    public A withNewType(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withType(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewType(String arg1) {
        return (A)withType(new String(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        StatefulSetUpdateStrategyFluentImpl that = (StatefulSetUpdateStrategyFluentImpl) o;
        if (rollingUpdate != null ? !rollingUpdate.equals(that.rollingUpdate) :that.rollingUpdate != null) return false;
        if (type != null ? !type.equals(that.type) :that.type != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(rollingUpdate,  type,  super.hashCode());
    }

    public class RollingUpdateNestedImpl<N> extends RollingUpdateStatefulSetStrategyFluentImpl<io.fabric8.kubernetes.api.model.apps.StatefulSetUpdateStrategyFluent.RollingUpdateNested<N>> implements io.fabric8.kubernetes.api.model.apps.StatefulSetUpdateStrategyFluent.RollingUpdateNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final RollingUpdateStatefulSetStrategyBuilder builder;

            RollingUpdateNestedImpl(RollingUpdateStatefulSetStrategy item) {
                this.builder = new RollingUpdateStatefulSetStrategyBuilder(this, item);
                        
            }

            RollingUpdateNestedImpl() {
                this.builder = new RollingUpdateStatefulSetStrategyBuilder(this);
                        
            }

            public N and() {
                return (N) StatefulSetUpdateStrategyFluentImpl.this.withRollingUpdate(builder.build());
            }

            public N endRollingUpdate() {
                return and();
            }
    }


}
